import { DropdownContainer, DropdownItem, DropdownItemContainer, DropdownTrigger, Icon } from '@/lib/components';
import { getDataTypeIcon } from '@/lib/components/DataTypeIcon';
import { Input } from '@/lib/components/inputs';
import React, { useState } from 'react';
import { SchemaAttributeTypes } from 'ts-common';

interface DropdownOption {
  name: string;
  type: string;
}

interface DropdownSelectorProps {
  label: string;
  selectedValue: string;
  options: DropdownOption[];
  filter: string;
  setFilter: (value: string) => void;
  onChange: (selected: DropdownOption) => void;
}

export const DropdownSelector: React.FC<DropdownSelectorProps> = ({ label, selectedValue, filter, setFilter, options, onChange }) => {
  const [open, setOpen] = useState(false);

  const filteredOptions = options.filter(option => option.name.toLowerCase().includes(filter.toLowerCase()));

  return (
    <DropdownContainer open={open} onOpenChange={setOpen}>
      <span>{label}</span>
      <DropdownTrigger title={selectedValue} size="md" variant="outline" onClick={() => setOpen(v => !v)} />
      <DropdownItemContainer className="max-h-none">
        <Input
          label=""
          type="text"
          placeholder="Filter"
          size="xs"
          className="mb-1 rounded-sm w-full"
          value={filter}
          onClick={e => e.stopPropagation()}
          onChange={v => setFilter(v)}
        />
        {filteredOptions.map(attr => (
          <DropdownItem
            key={attr.name + attr.type}
            value={attr.name}
            className="w-full"
            onClick={() => {
              onChange(attr);
              setOpen(false);
            }}
          >
            <div className="flex items-center gap-1">
              <Icon component={getDataTypeIcon(attr.type as SchemaAttributeTypes)} size={16} />
            </div>
          </DropdownItem>
        ))}
      </DropdownItemContainer>
    </DropdownContainer>
  );
};
