import React from 'react';
import { DropdownSelector } from '@/lib/components/DropdownSelector/DropdownSelector';
import { Input } from '@/lib/components/inputs';

interface Vis1DSettingsBarProps {
  settings: any;
  updateSettings: (updatedSettings: any) => void;
  attributeOptions: { name: string; type: string }[];
  filterYLabel: string;
  setFilterYLabel: React.Dispatch<React.SetStateAction<string>>;
  filterZLabel: string;
  setFilterZLabel: React.Dispatch<React.SetStateAction<string>>;
}

export const Vis1DSettingsBar = ({
  settings,
  updateSettings,
  attributeOptions,
  filterYLabel,
  setFilterYLabel,
  filterZLabel,
  setFilterZLabel,
}: Vis1DSettingsBarProps) => {
  return (
    <div>
      <div className="mb-2">
        <DropdownSelector
          label="Y Axis"
          selectedValue={settings.yAxisLabel.name}
          options={attributeOptions}
          filter={filterYLabel}
          setFilter={setFilterYLabel}
          onChange={selected => {
            if (selected.name === 'No selection') {
              updateSettings({ yAxisLabel: { name: '', type: '' } });
            } else {
              updateSettings({ yAxisLabel: { name: selected.name, type: selected.type } });
            }
          }}
        />
        <DropdownSelector
          label="Z Axis"
          selectedValue={settings.zAxisLabel.name}
          options={attributeOptions}
          filter={filterZLabel}
          setFilter={setFilterZLabel}
          onChange={selected => {
            if (selected.name === 'No selection') {
              updateSettings({ zAxisLabel: { name: '', type: '' } });
            } else {
              updateSettings({ zAxisLabel: { name: selected.name, type: selected.type } });
            }
          }}
        />
        {(settings.xAxisLabel.name?.includes('Datum') ||
          settings.xAxisLabel.type === 'date' ||
          settings.xAxisLabel.type === 'datetime') && (
          <div className="mb-2">
            <Input
              type="dropdown"
              label="Group Time:"
              value={settings.groupDataByTime}
              options={['', 'hourly', 'daily', 'weekly', 'monthly', 'quarterly', 'yearly']}
              onChange={value => {
                updateSettings({ groupDataByTime: value as string });
              }}
            />
          </div>
        )}
      </div>
    </div>
  );
};
