import React from 'react';
import { DropdownSelector } from '@/lib/components/DropdownSelector/DropdownSelector';
import { Input } from '@/lib/components/inputs';

interface Vis1DSettingsLineProps {
  settings: any;
  updateSettings: (updatedSettings: any) => void;
  attributeOptions: { name: string; type: string }[];
  filterYLabel: string;
  setFilterYLabel: React.Dispatch<React.SetStateAction<string>>;
}

export const Vis1DSettingsLine = ({
  settings,
  updateSettings,
  attributeOptions,
  filterYLabel,
  setFilterYLabel,
}: Vis1DSettingsLineProps) => {
  return (
    <div>
      <div className="mb-2">
        <DropdownSelector
          label="Y Axis"
          selectedValue={settings.yAxisLabel.name}
          options={attributeOptions}
          filter={filterYLabel}
          setFilter={setFilterYLabel}
          onChange={selected => {
            if (selected.name === 'No selection') {
              updateSettings({ yAxisLabel: { name: '', type: '' } });
            } else {
              updateSettings({ yAxisLabel: { name: selected.name, type: selected.type } });
            }
          }}
        />
        <div className="mb-2">
          <Input type="boolean" label="Stack: " value={settings.stack} onChange={val => updateSettings({ stack: val })} />
        </div>
        {(settings.xAxisLabel.name?.includes('Datum') ||
          settings.xAxisLabel.type === 'date' ||
          settings.xAxisLabel.type === 'datetime') && (
          <div className="mb-2">
            <Input
              type="dropdown"
              label="Group Time:"
              value={settings.groupDataByTime}
              options={['', 'hourly', 'daily', 'weekly', 'monthly', 'quarterly', 'yearly']}
              onChange={value => {
                updateSettings({ groupDataByTime: value as string });
              }}
            />
          </div>
        )}
      </div>
    </div>
  );
};
