import { GraphQueryResult } from '@/lib/data-access';
import { plotTypeOptions } from './components/MakePlot';
import { Vis1DInputData } from './componentsVIs1D/types';

type VariableSelection = {
  name: string;
  type: string;
};
export interface Vis1DProps {
  plotType: (typeof plotTypeOptions)[number];
  title: string;
  selectedEntity: string;
  xAxisLabel: VariableSelection;
  yAxisLabel: VariableSelection;
  zAxisLabel: VariableSelection;
  showAxis: boolean;
  //groupData?: 'quarterly' | 'hourly' | 'minutely' | 'yearly' | 'monthly' | undefined;
  groupDataByTime?: string;
  groupAggregation?: string;
  stack: boolean;
}

export enum Vis1DHistogramAggregation {
  COUNT = 'count',
  DEGREE = 'degree',
}
export const vis1DHistogramAggregationOptions = Object.values(Vis1DHistogramAggregation);

export interface Vis1DVisHandle {
  exportImageInternal: () => void;
}

export const getAttributeValuesSimple = (query: GraphQueryResult, selectedEntity: string, data: VariableSelection): Vis1DInputData => {
  if (!selectedEntity || !data.name || data.name === ' ') {
    return { data: [], type: data.type, label: data.name as string };
  }

  const attValues = query.graph.nodes
    .filter(item => item.label === selectedEntity)
    .map(item => {
      return item.attributes && data.name in item.attributes && item.attributes[data.name] !== ''
        ? (item.attributes[data.name] as string | number)
        : 'NoData';
    });

  return {
    data: attValues,
    type: data.type,
    label: data.name as string,
  };
};

export const getAttributeValues = (
  query: GraphQueryResult,
  selectedEntity: string,
  attributeKey: string | number | undefined,
  groupBy?: string,
): (string | number)[] => {
  if (!selectedEntity || !attributeKey) {
    return [];
  }

  if (attributeKey == ' ') {
    return [];
  }

  const attValues = query.graph.nodes
    .filter(item => item.label === selectedEntity)
    .map(item => {
      // Check if the attribute exists, return its value if it does, or an empty string otherwise
      return [
        item._id,
        item.attributes && attributeKey in item.attributes && item.attributes[attributeKey] !== ''
          ? (item.attributes[attributeKey] as string | number)
          : 'NoData',
      ];
    });
  //console.log('attValues ', attValues);
  const attValuesFilterd = attValues.map(e => e[1]);

  //const uniqueValues = Array.from(new Set(attValues.map(item => item[1])));
  return attValuesFilterd;
  /*
  if (!groupBy) {
    return uniqueValues;
  }
  
  if (groupBy === 'count') {
    const agg = Object.entries(
      attValues
        .map(item => item[1])
        .reduce(
          (acc, item) => {
            acc[item] = (acc[item] || 0) + 1;
            return acc;
          },
          {} as Record<string, number>,
        ),
    );
    const ret = agg
      .map(item => ({ id: item[0], value: item[1], position: uniqueValues.indexOf(item[0]) }))
      .sort((a, b) => a.position - b.position)
      .map(item => item.value);
    return ret;
  } else if (groupBy === 'degree') {
    const attValuesMap = Object.fromEntries(attValues);
    const ids = attValues.map(item => item[0]);
    const degree = query.graph.edges.reduce(
      (acc, item) => {
        if (ids.includes(item.from)) {
          acc[attValuesMap[item.from]] = (acc[attValuesMap[item.from]] || 0) + 1;
        } else if (ids.includes(item.to)) {
          acc[attValuesMap[item.to]] = (acc[attValuesMap[item.to]] || 0) + 1;
        }
        return acc;
      },
      {} as Record<string, number>,
    );
    return attValues
      .map(item => ({ id: item[0], value: degree[item[1]] || 0, position: uniqueValues.indexOf(item[0]) }))
      .sort((a, b) => a.position - b.position)
      .map(item => item.value);
  } else {
    console.error('Invalid groupBy value', groupBy);
    throw new Error('Invalid groupBy value');
  }
  */
};
