import { plotTypeOptions, Vis1DInputData } from '../componentsVIs1D/types';

import { preparePlotDataAndLayoutHistogramDegree } from './preparePlotHistogramDegree';
import { preparePlotDataAndLayoutHistogramCount } from './preparePlotHistogramCount';
import { preparePlotDataAndLayoutLine } from './preparePlotLine';
import { preparePlotDataAndLayoutBar } from './preparePlotBar';
import { preparePlotDataAndLayoutPie } from './preparePlotPie';
import { preparePlotDataAndLayoutScatter } from './preparePlotScatter';

export const prepareDataOrchestrator = (
  plotType: (typeof plotTypeOptions)[number],
  xData: Vis1DInputData,
  yData: Vis1DInputData,
  zData: Vis1DInputData,
  showAxis: boolean,
  stackVariable: boolean,
  groupDataByTime?: string,
  groupAggregation?: string,
) => {
  switch (plotType) {
    case 'bar':
      return preparePlotDataAndLayoutBar(xData, yData, zData, showAxis, groupDataByTime);
    case 'scatter':
      return preparePlotDataAndLayoutScatter(xData, yData, zData, showAxis);
    case 'line':
      return preparePlotDataAndLayoutLine(xData, yData, showAxis, groupDataByTime);
    case 'pie':
      return preparePlotDataAndLayoutPie(xData, showAxis);
    case 'histogram':
      switch (groupAggregation) {
        case 'count':
          return preparePlotDataAndLayoutHistogramCount(xData, yData, zData, showAxis, stackVariable);
        case 'degree':
          return preparePlotDataAndLayoutHistogramDegree(xData, yData, showAxis);
        default:
          throw new Error(`Unsupported group aggregation: ${groupAggregation}`);
      }
    default:
      throw new Error(`Unsupported plot type: ${plotType}`);
  }
};
