import { Vis1DInputData } from '../componentsVIs1D/types';
import { getCommonLayout, getCSSVariableHSL, sharedTickFont } from '../prepareLayout/LayoutCommon';
import { PlotType } from 'plotly.js';

export const preparePlotDataAndLayoutHistogramDegree = (xData: Vis1DInputData, yData: Vis1DInputData, showAxis: boolean) => {
  const primaryColor = getCSSVariableHSL('--clr-sec--400');

  const combinedData = xData.data.map((xValue, index) => ({
    x: xValue,
    y: yData.data[index],
  }));

  const sortedData = combinedData.sort((a, b) => Number(b.y) - Number(a.y));

  const sortedXValues = sortedData.map(item => item.x);
  const sortedYValues = sortedData.map(item => item.y);

  const traces = [
    {
      type: 'bar' as PlotType,
      x: sortedXValues,
      y: sortedYValues,
      marker: { color: primaryColor },
    },
  ];

  const layout: Partial<Plotly.Layout> = getCommonLayout({
    showAxis,
    xAxisLabel: 'Nodes',
    yAxisLabel: 'Count',
    xValues: xData.data,
    yValues: xData.data,
    plotType: 'bar',
    xAxisData: xData.data,
    sortedLabels: sortedXValues,
    sharedTickFont,
  });

  return { data: traces, layout };
};
