import { Vis1DInputData } from '../componentsVIs1D/types';
import { getCommonLayout, getCSSVariableHSL, sharedTickFont } from '../prepareLayout/LayoutCommon';
import { PlotType } from 'plotly.js';
import { groupByTime } from './utilsTime';

export const preparePlotDataAndLayoutLine = (xData: Vis1DInputData, yData: Vis1DInputData, showAxis: boolean, groupDataByTime?: string) => {
  const primaryColor = getCSSVariableHSL('--clr-sec--400');

  // data preparation
  let xValues: (string | number)[] = [];
  let yValues: (string | number)[] = [];

  if (groupDataByTime !== undefined) {
    if (yData.data && yData.data.length !== 0) {
      const { xValuesGrouped, yValuesGrouped } = groupByTime(xData.data as string[], groupDataByTime, yData.data);
      xValues = xValuesGrouped;
      yValues = yValuesGrouped.flat();
    } else {
      const { xValuesGrouped, yValuesGrouped } = groupByTime(xData.data as string[], groupDataByTime);
      xValues = xValuesGrouped;
      yValues = yValuesGrouped.flat();
    }
  } else {
    if (xData.data.length !== 0 && yData && yData.data.length !== 0) {
      xValues = xData.data;
      yValues = yData.data;
    } else if (xData.data.length !== 0 && (!yData || yData.data.length === 0)) {
      xValues = xData.data;
      yValues = xData.data.map((_, index) => index + 1);
    } else if (xData.data.length === 0 && yData && yData.data.length !== 0) {
      xValues = yData.data.map((_, index) => index + 1);
      yValues = yData.data;
    }
  }

  const data: Plotly.Data[] = [
    {
      type: 'scatter' as PlotType,
      x: xValues,
      y: yValues,
      mode: 'lines' as const,
      line: { color: primaryColor },
      customdata: xValues.map(label => (label === 'undefined' || label === 'null' || label === '' ? 'nonData' : '')),
      hovertemplate: '<b>%{customdata}</b><extra></extra>',
    },
  ];

  const layout: Partial<Plotly.Layout> = getCommonLayout({
    showAxis,
    xAxisLabel: xData.label,
    yAxisLabel: yData.label,
    xValues,
    yValues,
    plotType: 'line',
    xAxisData: xValues,
    sortedLabels: [],
    sharedTickFont,
  });

  return { data, layout };
};
