import { computeStringTickValues } from '../prepareData/utils';

interface LayoutProps {
  showAxis: boolean;
  xAxisLabel: string;
  yAxisLabel: string;
  xValues: any[];
  yValues: any[];
  plotType: 'scatter' | 'line' | 'histogram' | 'bar';
  xAxisData: any[];
  sortedLabels: any[];
  sharedTickFont: { family: string; size: number; color: string };
}

export const getCommonLayout = ({
  showAxis,
  xAxisLabel,
  yAxisLabel,
  xValues,
  yValues,
  plotType,
  xAxisData,
  sortedLabels,
  sharedTickFont,
}: LayoutProps): Partial<Plotly.Layout> => {
  const lengthLabelsX = 7; // !TODO computed number of elements based
  const lengthLabelsY = 8; // !TODO computed number of elements based

  let truncatedXLabels: string[] = [];
  let truncatedYLabels: string[] = [];

  if (typeof xValues[0] === 'string') {
    truncatedXLabels = computeStringTickValues(xValues, 2, lengthLabelsX);
  }

  if (typeof yValues[0] === 'string' && (plotType === 'scatter' || plotType === 'line')) {
    truncatedYLabels = computeStringTickValues(yValues, 2, lengthLabelsY);
  }

  return {
    barmode: 'stack',
    xaxis: {
      title: {
        text: showAxis ? (xAxisLabel ? xAxisLabel : '') : '',
        standoff: 30,
      },
      tickfont: sharedTickFont,
      showgrid: false,
      visible: showAxis,
      ...(typeof xAxisData[0] === 'string' || (plotType === 'histogram' && sortedLabels.length > 0)
        ? { type: 'category', categoryarray: sortedLabels, categoryorder: 'array' }
        : {}),
      showline: true,
      zeroline: false,
      tickvals: typeof xValues[0] === 'string' ? xValues : undefined,
      ticktext: typeof xValues[0] === 'string' ? truncatedXLabels : undefined,
    },

    yaxis: {
      showgrid: false,
      visible: showAxis,
      showline: true,
      zeroline: false,
      tickfont: sharedTickFont,
      title: {
        text: showAxis ? (yAxisLabel ? yAxisLabel : '') : '',
        standoff: 30,
      },
      tickvals: typeof yValues[0] === 'string' && (plotType === 'scatter' || plotType === 'line') ? yValues : undefined,
      ticktext: typeof yValues[0] === 'string' && (plotType === 'scatter' || plotType === 'line') ? truncatedYLabels : undefined,
    },

    font: {
      family: 'Inter',
      size: 12,
      color: '#374151',
    },

    hoverlabel: {
      bgcolor: 'rgba(255, 255, 255, 0.8)',
      bordercolor: 'rgba(0, 0, 0, 0.2)',
      font: {
        family: 'Inter',
        size: 13,
        color: '#374151',
      },
    },
  };
};

export const getCSSVariableHSL = (varName: string) => {
  const rootStyles = getComputedStyle(document.documentElement);
  const hslValue = rootStyles.getPropertyValue(varName).trim().replace('deg', '');
  return `hsl(${hslValue})`;
};

export const sharedTickFont = {
  family: 'Inter',
  size: 11,
  color: '#374151',
};
